aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/analysis/test
diff options
context:
space:
mode:
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/analysis/test')
-rw-r--r--src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java b/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
index 44ae134d9d..885f42bbdf 100644
--- a/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
+++ b/src/main/java/com/google/devtools/build/lib/analysis/test/TestActionContext.java
@@ -20,7 +20,7 @@ import com.google.devtools.build.lib.actions.SpawnResult;
import com.google.devtools.build.lib.vfs.Path;
import com.google.devtools.build.lib.view.test.TestStatus.TestResultData;
import java.io.IOException;
-import java.util.Set;
+import java.util.List;
/**
* A context for the execution of test actions ({@link TestRunnerAction}).
@@ -31,9 +31,9 @@ public interface TestActionContext extends ActionContext {
* Executes the test command, directing standard out / err to {@code outErr}. The status of the
* test should be communicated by posting a {@link TestResult} object to the eventbus.
*
* @return a set of SpawnResults created during execution of the test command, if any
*/
- Set<SpawnResult> exec(TestRunnerAction action, ActionExecutionContext actionExecutionContext)
+ List<SpawnResult> exec(TestRunnerAction action, ActionExecutionContext actionExecutionContext)
throws ExecException, InterruptedException;
/**
@@ -31,9 +31,9 @@ public interface TestActionContext extends ActionContext {
* test should be communicated by posting a {@link TestResult} object to the eventbus.
*
- * @return a set of SpawnResults created during execution of the test command, if any
+ * @return a list of SpawnResults created during execution of the test command, if any
*/